# IMPORTANT: this file is autogenerated. Do not edit it manually.
{% for req in package.all_requires %}
    {% if req.is_optional() == optional %}
        {% if req.is_vcs() %}
            -e {{ format_vcs(req) }}
        {% else %}
            {{ req.to_pep_508() }}
        {% endif %}
    {% endif %}
{% endfor %}
